@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* GIO - GLib Input, Output and Streaming Library
  * 
  * Copyright (C) 2008 Benjamin Otte <otte@gnome.org>
@@ -181,10 +180,10 @@ gvfs_archive_pop_job (GVfsArchive *archive)
     }
   else if (archive_errno (archive->archive))
     {
-      g_vfs_job_failed (archive->job,
-			G_IO_ERROR,
-			archive_errno (archive->archive),
-			archive_error_string (archive->archive));
+      g_vfs_job_failed_literal (archive->job,
+				G_IO_ERROR,
+				archive_errno (archive->archive),
+				archive_error_string (archive->archive));
     }
   else
     g_vfs_job_succeeded (archive->job);
@@ -458,8 +457,14 @@ create_file_tree (GVfsBackendArchive *ba, GVfsJob *job)
   do
     {
       result = archive_read_next_header (archive->archive, &entry);
-      if (result == ARCHIVE_OK)
+      if (result >= ARCHIVE_WARN && result <= ARCHIVE_OK)
 	{
+  	  if (result < ARCHIVE_OK) {
+  	    DEBUG ("archive_read_next_header: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
+  	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
+  	    archive_clear_error (archive->archive);
+	  }
+  
 	  ArchiveFile *file = archive_file_get_from_path (ba->files, 
 	                                                  archive_entry_pathname (entry), 
 							  TRUE);
@@ -601,8 +606,14 @@ do_open_for_read (GVfsBackend *       backend,
   do
     {
       result = archive_read_next_header (archive->archive, &entry);
-      if (result == ARCHIVE_OK)
+      if (result >= ARCHIVE_WARN && result <= ARCHIVE_OK)
         {
+	  if (result < ARCHIVE_OK) {
+	    DEBUG ("do_open_for_read: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
+	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
+	    archive_clear_error (archive->archive);
+	  }
+                              
           if (g_str_equal (archive_entry_pathname (entry), filename + 1))
             {
               /* SUCCESS */
